﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Drawing;
using System.Globalization;

namespace HeuristicLab.Persistence.Default.Xml.Primitive {
  internal sealed class Font2XmlSerializer : PrimitiveXmlSerializerBase<Font> {

    public override XmlString Format(Font font) {
      if (font != null) {
        return new XmlString(font.Name
          + ";" + font.SizeInPoints.ToString(CultureInfo.InvariantCulture.NumberFormat)
          + ";" + font.Style.ToString("d")
          + ";" + font.GdiCharSet.ToString());
      }
      return new XmlString(string.Empty);
    }

    public override Font Parse(XmlString fontData) {
      if (string.IsNullOrEmpty(fontData.Data)) return null;
      string[] tokens = fontData.Data.Split(';');
      if (tokens.Length < 4) return null;
      float size = 12.0f;
      FontStyle style = FontStyle.Regular;
      byte gdiCharSet = 1;
      if (!float.TryParse(tokens[1], NumberStyles.Float, CultureInfo.InvariantCulture.NumberFormat, out size))
        return null;
      if (!Enum.TryParse(tokens[2], out style))
        return null;
      if (!byte.TryParse(tokens[3], out gdiCharSet))
        return null;

      return new Font(tokens[0], size, style, GraphicsUnit.Point, gdiCharSet);
    }
  }
}
